##  Custom Configurations
It is possible to sync records between custom tables, fields, and also CMDB tables not part of the figures shown above. However, it is not possible to fully support all use cases in all conditions and has to be reviewed on a case-by-case basis.
